---
name: Other
about: 'Report some other kind of a problem'
title: ''
labels: triage
assignees: ''

---

#### Software information (if applicable)
Please, provide information about your software:
- Operating System:
- `python==`
- `delu==`
- (other packages that you think may be important)

#### Describe the issue
